@@ -71,8 +71,11 @@ class Q_QUICKTEMPLATES2_PRIVATE_EXPORT QQuickSpinBox : public QQuickControl
     Q_PROPERTY(QJSValue valueFromText READ valueFromText WRITE setValueFromText NOTIFY valueFromTextChanged FINAL)
     Q_PROPERTY(QQuickSpinButton *up READ up CONSTANT FINAL)
     Q_PROPERTY(QQuickSpinButton *down READ down CONSTANT FINAL)
+    // 2.2 (Qt 5.9)
     Q_PROPERTY(Qt::InputMethodHints inputMethodHints READ inputMethodHints WRITE setInputMethodHints NOTIFY inputMethodHintsChanged FINAL REVISION 2)
     Q_PROPERTY(bool inputMethodComposing READ isInputMethodComposing NOTIFY inputMethodComposingChanged FINAL REVISION 2)
+    // 2.3 (Qt 5.10)
+    Q_PROPERTY(bool wrap READ wrap WRITE setWrap NOTIFY wrapChanged FINAL REVISION 3)
 
 public:
     explicit QQuickSpinBox(QQuickItem *parent = nullptr);
@@ -104,11 +107,16 @@ public:
     QQuickSpinButton *up() const;
     QQuickSpinButton *down() const;
 
+    // 2.2 (Qt 5.9)
     Qt::InputMethodHints inputMethodHints() const;
     void setInputMethodHints(Qt::InputMethodHints hints);
 
     bool isInputMethodComposing() const;
 
+    // 2.3 (Qt 5.10)
+    bool wrap() const;
+    void setWrap(bool wrap);
+
 public Q_SLOTS:
     void increase();
     void decrease();
@@ -122,9 +130,12 @@ Q_SIGNALS:
     void validatorChanged();
     void textFromValueChanged();
     void valueFromTextChanged();
+    // 2.2 (Qt 5.9)
     Q_REVISION(2) void valueModified();
     Q_REVISION(2) void inputMethodHintsChanged();
     Q_REVISION(2) void inputMethodComposingChanged();
+    // 2.3 (Qt 5.10)
+    Q_REVISION(3) void wrapChanged();
 
 protected:
     void focusInEvent(QFocusEvent *event) override;
@@ -143,9 +154,11 @@ protected:
     void contentItemChange(QQuickItem *newItem, QQuickItem *oldItem) override;
 
     QFont defaultFont() const override;
+    QPalette defaultPalette() const override;
 
 #if QT_CONFIG(accessibility)
     QAccessible::Role accessibleRole() const override;
+    void accessibilityActiveChanged(bool active) override;
 #endif
 
 private:
@@ -157,8 +170,9 @@ class Q_QUICKTEMPLATES2_PRIVATE_EXPORT QQuickSpinButton : public QObject
 {
     Q_OBJECT
     Q_PROPERTY(bool pressed READ isPressed WRITE setPressed NOTIFY pressedChanged FINAL)
-    Q_PROPERTY(bool hovered READ isHovered WRITE setHovered NOTIFY hoveredChanged FINAL REVISION 1)
     Q_PROPERTY(QQuickItem *indicator READ indicator WRITE setIndicator NOTIFY indicatorChanged FINAL)
+    // 2.1 (Qt 5.8)
+    Q_PROPERTY(bool hovered READ isHovered WRITE setHovered NOTIFY hoveredChanged FINAL REVISION 1)
 
 public:
     explicit QQuickSpinButton(QQuickSpinBox *parent);
@@ -166,16 +180,18 @@ public:
     bool isPressed() const;
     void setPressed(bool pressed);
 
-    bool isHovered() const;
-    void setHovered(bool hovered);
-
     QQuickItem *indicator() const;
     void setIndicator(QQuickItem *indicator);
 
+    // 2.1 (Qt 5.8)
+    bool isHovered() const;
+    void setHovered(bool hovered);
+
 Q_SIGNALS:
     void pressedChanged();
-    Q_REVISION(1) void hoveredChanged();
     void indicatorChanged();
+    // 2.1 (Qt 5.8)
+    Q_REVISION(1) void hoveredChanged();
 
 private:
     Q_DISABLE_COPY(QQuickSpinButton)
